@@ -31,6 +31,7 @@ from wrong_password import _WrongPassword
 from vkeyboard import handleVisibleChanged
 if sys.platform == 'linux':
     from  on_off.mainboard_pio import fanTurnOn
+    #from  on_off.mainbaord_pio import hub_reset
 currentPath=pathlib.Path(__file__).parent.absolute()
 
 
@@ -277,7 +278,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 
             elif slotNo == NON_SLOT_INDEX:
                 for i in range(TOTAL_SLOTS):
-                    self.slots[i].setStatus(SLOT_STATUS_WARNING, 'CR Error')
+                    self.slots[i].setStatus(SLOT_STATUS_WARNING, 'Checking...')
             elif errCode == DEVICE_STATE_TAKING_PHOTO:
                 self.slots[item[0]].detecting_(qrCode)
                 
