@@ -19,6 +19,9 @@ import wrong_password
 class _TestInfo(QtWidgets.QDialog):
     def __init__(self,parent=None):
         super(_TestInfo, self).__init__(parent)
+        self.profile = main_paras.info.getProfile(main_paras.sign_in_user)
+        self.last_scroll_value=0
+        self.original = True
 
 
         loadUi(os.path.join(currentdir,'test_info.ui'),self)
@@ -26,8 +29,6 @@ class _TestInfo(QtWidgets.QDialog):
 #        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
         flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
         self.setWindowFlags(flags)
-        self.last_scroll_value=0
-        self.original = True
 
     def scrolled(self):
         try:
@@ -61,10 +62,21 @@ class _TestInfo(QtWidgets.QDialog):
             self.back.clicked.connect(self.close)
             self.continue_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))            
             self.continue_bt.clicked.connect(self.continue_bt_hook)
-            self.place.setText(main_paras.test_place)
-            self.city.setText(main_paras.test_city)
-            self.country.setText(main_paras.test_country)
-            self.provider.setText(main_paras.test_provider)
+            
+            if main_paras.sign_in_user == 'feng.gao@laipac.com':
+                if self.profile['place'] =='':
+                    self.profile['place']='Office'
+                if self.profile['city'] =='':
+                    self.profile['city']='Markham'
+                if self.profile['country'] =='':
+                    self.profile['country']='Canada'
+                if self.profile['provider'] =='':
+                    self.profile['provider']='Laipac'
+
+            self.place.setText(self.profile['place'])
+            self.city.setText(self.profile['city'])
+            self.country.setText(self.profile['country'])
+            self.provider.setText(self.profile['provider'])
             
         except Exception as error:
             print(error)
@@ -93,11 +105,12 @@ class _TestInfo(QtWidgets.QDialog):
     def continue_bt_hook(self):
         try:
             if self.fieldCheck():
-                main_paras.test_place = self.place.text()
-                main_paras.test_city  = self.city.text()
-                main_paras.test_country = self.country.text()
-                main_paras.test_provider = self.provider.text()
+                self.profile['place'] = self.place.text()
+                self.profile['city']  = self.city.text()
+                self.profile['country'] = self.country.text()
+                self.profile['provider'] = self.provider.text()
                 main_paras.test_basic_info = True
+                main_paras.info.setProfile(self.profile)
                 self.close()
         except Exception as error:
             print(error)
